@@ -32,7 +32,9 @@ test_that("Hover on user function works", {
     writeLines(
         c(
             "test1 <- function(x, y) x + 1",
-            "test1"
+            "test1",
+            "test2 = function(x, y) x - 1",
+            "test2"
         ),
         temp_file
     )
@@ -43,6 +45,49 @@ test_that("Hover on user function works", {
     expect_length(result$contents, 1)
     expect_equal(result$contents[1], "```r\ntest1(x, y)\n```")
     expect_equal(result$range$end$character, 5)
+
+    result <- client %>% respond_hover(temp_file, c(3, 3))
+    expect_length(result$contents, 1)
+    expect_equal(result$contents[1], "```r\ntest2(x, y)\n```")
+    expect_equal(result$range$end$character, 5)
+})
+
+test_that("Hover on user function with multi-lined arguments works", {
+    skip_on_cran()
+    client <- language_client()
+
+    temp_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(
+        c(
+            "test1 <- function(",
+            "  x, # arg 1",
+            "  y  # arg 2",
+            ") {",
+            "    x + y",
+            "}",
+            "test1",
+            "test2 = function(",
+            "  x, # arg 1",
+            "  y  # arg 2",
+            ") {",
+            "    x + y",
+            "}",
+            "test2"
+        ),
+        temp_file
+    )
+
+    client %>% did_save(temp_file)
+
+    result <- client %>% respond_hover(temp_file, c(6, 3))
+    expect_length(result$contents, 1)
+    expect_equal(result$contents[1], "```r\ntest1(x, y)\n```")
+    expect_equal(result$range$end$character, 5)
+
+    result <- client %>% respond_hover(temp_file, c(13, 3))
+    expect_length(result$contents, 1)
+    expect_equal(result$contents[1], "```r\ntest2(x, y)\n```")
+    expect_equal(result$range$end$character, 5)
 })
 
 test_that("Hover on variable works", {
@@ -92,6 +137,85 @@ test_that("Hover on variable works", {
     expect_equal(result$contents, "```r\nvar1 <- 0\n```")
 })
 
+test_that("Hover on variable with leading tabs works", {
+    skip_on_cran()
+    client <- language_client()
+
+    temp_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(
+        c(
+            "index1 <- 1:10",
+            "\tindex1 + 1",
+            "\t\tindex1 + 2"
+        ),
+        temp_file
+    )
+
+    client %>% did_save(temp_file)
+
+    result <- client %>% respond_hover(temp_file, c(0, 1))
+    expect_equal(result$range$start, list(line = 0, character = 0))
+    expect_equal(result$range$end, list(line = 0, character = 6))
+    expect_equal(result$contents, "```r\nindex1 <- 1:10\n```")
+
+    result <- client %>% respond_hover(temp_file, c(1, 4))
+    expect_equal(result$range$start, list(line = 1, character = 1))
+    expect_equal(result$range$end, list(line = 1, character = 7))
+    expect_equal(result$contents, "```r\nindex1 <- 1:10\n```")
+
+    result <- client %>% respond_hover(temp_file, c(2, 7))
+    expect_equal(result$range$start, list(line = 2, character = 2))
+    expect_equal(result$range$end, list(line = 2, character = 8))
+    expect_equal(result$contents, "```r\nindex1 <- 1:10\n```")
+})
+
+test_that("Hover on variable works with semi-colons", {
+    skip_on_cran()
+    client <- language_client()
+
+    temp_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(
+        c(
+            "var1 <- 1:10;",
+            "f(var1)",
+            "local({",
+            "   var2 <- 2:10;",
+            "   f(var1, var2)",
+            "   var1 <- 0;",
+            "   f(var1, var2)",
+            "})"
+        ),
+        temp_file
+    )
+
+    client %>% did_save(temp_file)
+
+    result <- client %>% respond_hover(temp_file, c(0, 1))
+    expect_equal(result$range$start, list(line = 0, character = 0))
+    expect_equal(result$range$end, list(line = 0, character = 4))
+    expect_equal(result$contents, "```r\nvar1 <- 1:10;\n```")
+
+    result <- client %>% respond_hover(temp_file, c(1, 3))
+    expect_equal(result$range$start, list(line = 1, character = 2))
+    expect_equal(result$range$end, list(line = 1, character = 6))
+    expect_equal(result$contents, "```r\nvar1 <- 1:10;\n```")
+
+    result <- client %>% respond_hover(temp_file, c(4, 6))
+    expect_equal(result$range$start, list(line = 4, character = 5))
+    expect_equal(result$range$end, list(line = 4, character = 9))
+    expect_equal(result$contents, "```r\nvar1 <- 1:10;\n```")
+
+    result <- client %>% respond_hover(temp_file, c(4, 13))
+    expect_equal(result$range$start, list(line = 4, character = 11))
+    expect_equal(result$range$end, list(line = 4, character = 15))
+    expect_equal(result$contents, "```r\nvar2 <- 2:10;\n```")
+
+    result <- client %>% respond_hover(temp_file, c(6, 6))
+    expect_equal(result$range$start, list(line = 6, character = 5))
+    expect_equal(result$range$end, list(line = 6, character = 9))
+    expect_equal(result$contents, "```r\nvar1 <- 0;\n```")
+})
+
 test_that("Hover works in scope with different assignment operators", {
     skip_on_cran()
     client <- language_client()
@@ -308,6 +432,33 @@ test_that("Hover works with local function", {
     ))
 })
 
+test_that("Hover on operator is ignored", {
+    skip_on_cran()
+    client <- language_client()
+
+    temp_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(
+        c(
+            "for (ll in 1:3) {",
+            " p = ll",
+            " I = array(0:0, dim=c(p,p))",
+            "}"
+        ),
+        temp_file
+    )
+
+    client %>% did_save(temp_file)
+
+    result <- client %>% respond_hover(temp_file, c(2, 22),
+        retry_when = function(result) length(result) > 0)
+    expect_equal(result, NULL)
+
+    result <- client %>% respond_hover(temp_file, c(2, 23))
+    expect_equal(result$range$start, list(line = 2, character = 22))
+    expect_equal(result$range$end, list(line = 2, character = 23))
+    expect_equal(result$contents, "```r\np = ll\n```")
+})
+
 test_that("Hover works across multiple files", {
     skip_on_cran()
     client <- language_client()
